@@ -4,16 +4,16 @@ use warnings;
 our (%gui, %signal, %vmc);
 
 sub init_edit_storage {
-    &busy_pointer($gui{dialogEdit}, 1);
+    &set_pointer($gui{dialogEdit}, 'watch');
     my $vhost = &vhost();
     &fill_list_editstorage($vmc{IMachine});
-    $gui{menuAttachAdd} = Gtk2::Menu->new();
-    $gui{menuAttachHD} = Gtk2::Menu->new();
-    $gui{menuAttachDVD} = Gtk2::Menu->new();
-    $gui{menuAttachFloppy} = Gtk2::Menu->new();
-    $gui{menuitemAttachHD} = Gtk2::MenuItem->new_with_label('Hard Disks');
-    $gui{menuitemAttachDVD} = Gtk2::MenuItem->new_with_label('Optical Discs');
-    $gui{menuitemAttachFloppy} = Gtk2::MenuItem->new_with_label('Floppy Disks');
+    $gui{menuAttachAdd} = Gtk3::Menu->new();
+    $gui{menuAttachHD} = Gtk3::Menu->new();
+    $gui{menuAttachDVD} = Gtk3::Menu->new();
+    $gui{menuAttachFloppy} = Gtk3::Menu->new();
+    $gui{menuitemAttachHD} = Gtk3::MenuItem->new_with_label('Hard Disks');
+    $gui{menuitemAttachDVD} = Gtk3::MenuItem->new_with_label('Optical Discs');
+    $gui{menuitemAttachFloppy} = Gtk3::MenuItem->new_with_label('Floppy Disks');
     $gui{menuitemAttachHD}->set_submenu($gui{menuAttachHD});
     $gui{menuitemAttachDVD}->set_submenu($gui{menuAttachDVD});
     $gui{menuitemAttachFloppy}->set_submenu($gui{menuAttachFloppy});
@@ -24,25 +24,25 @@ sub init_edit_storage {
     $gui{menuAttachAdd}->append($gui{menuitemAttachDVD});
     $gui{menuAttachAdd}->append($gui{menuitemAttachFloppy});
 
-    my $newhditem = Gtk2::MenuItem->new_with_label('Create New Hard Disk');
+    my $newhditem = Gtk3::MenuItem->new_with_label('Create New Hard Disk');
     $gui{menuAttachHD}->append($newhditem);
     $newhditem->show();
     $newhditem->signal_connect(activate => \&show_dialog_createhd);
-    my $hdsep = Gtk2::SeparatorMenuItem->new();
+    my $hdsep = Gtk3::SeparatorMenuItem->new();
     $gui{menuAttachHD}->append($hdsep);
     $hdsep->show();
 
-    my $emptydvditem = Gtk2::MenuItem->new_with_label('<Empty Drive>');
+    my $emptydvditem = Gtk3::MenuItem->new_with_label('<Empty Drive>');
     $gui{menuAttachDVD}->append($emptydvditem);
     $emptydvditem->show();
     $emptydvditem->signal_connect(activate => \&storage_attach_dvd, '');
-    my $dvdsep = Gtk2::SeparatorMenuItem->new();
+    my $dvdsep = Gtk3::SeparatorMenuItem->new();
     $gui{menuAttachDVD}->append($dvdsep);
     $dvdsep->show();
 
-    my $newfloppyitem = Gtk2::MenuItem->new_with_label('Create New Floppy Disk');
-    my $emptyfloppyitem = Gtk2::MenuItem->new_with_label('<Empty Drive>');
-    my $floppysep = Gtk2::SeparatorMenuItem->new();
+    my $newfloppyitem = Gtk3::MenuItem->new_with_label('Create New Floppy Disk');
+    my $emptyfloppyitem = Gtk3::MenuItem->new_with_label('<Empty Drive>');
+    my $floppysep = Gtk3::SeparatorMenuItem->new();
     $gui{menuAttachFloppy}->append($newfloppyitem);
     $gui{menuAttachFloppy}->append($floppysep);
     $floppysep->show();
@@ -51,7 +51,7 @@ sub init_edit_storage {
     $newfloppyitem->show();
     $emptyfloppyitem->signal_connect(activate => \&storage_attach_floppy, '');
     $newfloppyitem->signal_connect(activate => \&show_dialog_createfloppy);
-    my $floppysep2 = Gtk2::SeparatorMenuItem->new();
+    my $floppysep2 = Gtk3::SeparatorMenuItem->new();
     $gui{menuAttachFloppy}->append($floppysep2);
     $floppysep2->show();
 
@@ -60,7 +60,7 @@ sub init_edit_storage {
     my $IMediumFloppyRef = &get_all_media('Floppy');
 
     foreach (sort { lc($$IMediumHDRef{$a}) cmp lc($$IMediumHDRef{$b}) } (keys %$IMediumHDRef)) {
-        my $item = Gtk2::MenuItem->new_with_label($$IMediumHDRef{$_});
+        my $item = Gtk3::MenuItem->new_with_label($$IMediumHDRef{$_});
         $gui{menuAttachHD}->append($item);
         $item->show();
         $item->signal_connect(activate => \&storage_attach_hd, $_);
@@ -68,19 +68,19 @@ sub init_edit_storage {
 
     if ($$vhost{dvd}) {
         foreach my $pdvd (@{$$vhost{dvd}}) {
-            my $item = Gtk2::MenuItem->new_with_label('<Server Drive> ' . IMedium_getLocation($pdvd));
+            my $item = Gtk3::MenuItem->new_with_label('<Server Drive> ' . IMedium_getLocation($pdvd));
             $gui{menuAttachDVD}->append($item);
             $item->show();
             $item->signal_connect(activate => \&storage_attach_dvd, $pdvd);
         }
 
-        my $pdvdsep = Gtk2::SeparatorMenuItem->new();
+        my $pdvdsep = Gtk3::SeparatorMenuItem->new();
         $gui{menuAttachDVD}->append($pdvdsep);
         $pdvdsep->show();
     }
 
     foreach (sort { lc($$IMediumDVDRef{$a}) cmp lc($$IMediumDVDRef{$b}) } (keys %$IMediumDVDRef)) {
-        my $item = Gtk2::MenuItem->new_with_label($$IMediumDVDRef{$_});
+        my $item = Gtk3::MenuItem->new_with_label($$IMediumDVDRef{$_});
         $gui{menuAttachDVD}->append($item);
         $item->show();
         $item->signal_connect(activate => \&storage_attach_dvd, $_);
@@ -88,25 +88,25 @@ sub init_edit_storage {
 
     if ($$vhost{floppy}) {
         foreach my $pfloppy (@{$$vhost{floppy}}) {
-            my $item = Gtk2::MenuItem->new_with_label('<Server Drive> ' . IMedium_getLocation($pfloppy));
+            my $item = Gtk3::MenuItem->new_with_label('<Server Drive> ' . IMedium_getLocation($pfloppy));
             $gui{menuAttachFloppy}->append($item);
             $item->show();
             $item->signal_connect(activate => \&storage_attach_floppy, $pfloppy);
         }
 
-        my $pfloppysep = Gtk2::SeparatorMenuItem->new();
+        my $pfloppysep = Gtk3::SeparatorMenuItem->new();
         $gui{menuAttachDVD}->append($pfloppysep);
         $pfloppysep->show();
     }
 
     foreach (sort { lc($$IMediumFloppyRef{$a}) cmp lc($$IMediumFloppyRef{$b}) } (keys %$IMediumFloppyRef)) {
-        my $item = Gtk2::MenuItem->new_with_label($$IMediumFloppyRef{$_});
+        my $item = Gtk3::MenuItem->new_with_label($$IMediumFloppyRef{$_});
         $gui{menuAttachFloppy}->append($item);
         $item->show();
         $item->signal_connect(activate => \&storage_attach_floppy, $_);
     }
 
-    &busy_pointer($gui{dialogEdit}, 0);
+    &set_pointer($gui{dialogEdit});
 }
 
 # Displays the create a new floppy disk dialog. Creates & attaches based on options
@@ -161,7 +161,7 @@ sub show_dialog_createfloppy {
         }
         else { $gui{dialogCreateFloppy}->hide; }
 
-    } until (!$gui{dialogCreateFloppy}->visible());
+    } until (!$gui{dialogCreateFloppy}->get_visible());
 }
 
 # Displays the create a new hard disk dialog. Creates & attaches based on options
@@ -222,7 +222,7 @@ sub show_dialog_createhd {
         }
         else { $gui{dialogCreateHD}->hide; }
 
-    } until (!$gui{dialogCreateHD}->visible());
+    } until (!$gui{dialogCreateHD}->get_visible());
 }
 
 # Handle the radio button sensitivity when selecting an image format when
