@@ -95,7 +95,7 @@ our (%gui, $sharedir);
             if (!defined($osfam{$$type{familyId}})) {
                 $osfam{$$type{familyId}} = {};
                 $osfam{$$type{familyId}}{verids} = ();
-                $osfam{$$type{familyId}}{icon} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/$$type{familyId}.png");
+                $osfam{$$type{familyId}}{icon} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/$$type{familyId}.png");
             }
 
             $osfam{$$type{familyId}}{description} = $$type{familyDescription};
@@ -126,29 +126,32 @@ our (%gui, $sharedir);
             $osver{$$type{id}}{recommended2DVideoAcceleration} = $$type{recommended2DVideoAcceleration};
             $osver{$$type{id}}{recommendedAudioController} = $$type{recommendedAudioController};
             $osver{$$type{id}}{familyId} = $$type{familyId};
-            if (-e "$sharedir/icons/os/$$type{id}.png") { $osver{$$type{id}}{icon} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/$$type{id}.png"); }
+            if (-e "$sharedir/icons/os/$$type{id}.png") { $osver{$$type{id}}{icon} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/$$type{id}.png"); }
             elsif ($$type{id} =~ m/_64$/) { $osver{$$type{id}}{icon} = $gui{img}{OtherOS64}; }
             else { $osver{$$type{id}}{icon} = $gui{img}{OtherOS}; }
         }
     }
 }
 
-# Image formats to file extensions
-{
-    my %fileext = (cue       => 'cue',
-                   dmg       => 'dmg',
-                   parallels => 'hdd',
-                   qcow      => 'qcow',
-                   qed       => 'qed',
-                   raw       => 'img',
-                   vdi       => 'vdi',
-                   vhd       => 'vhd',
-                   vmdk      => 'vmdk');
+# Adds a file extention based on file type, if required
+sub add_ext_if_needed {
+    my ($file, $type) = @_;
+    $type = lc($type);
 
-    sub fileext { return \%fileext; }
+    my %filetypes = (cue       => '.cue',
+                     dmg       => '.dmg',
+                     parallels => '.hdd',
+                     qcow      => '.qcow',
+                     qed       => '.qed',
+                     raw       => '.img',
+                     vdi       => '.vdi',
+                     vhd       => '.vhd',
+                     vmdk      => '.vmdk');
+
+    $file .= $filetypes{$type} if ($file !~ m/$filetypes{$type}$/i);
+    return $file;
 }
 
-
 # Expects a hash reference as an input and populates the hash with IMedium
 # attributes, if that attribute has already been defined. The second argument
 # is the IMedium virtualbox reference
@@ -246,7 +249,7 @@ sub get_icontroller_attrs {
 {
     my @rdp_preset_tbl = ({num => 1, desc => 'FreeRDP',                    command => 'xfreerdp /size:%Xx%Y /bpp:32 +clipboard /sound /t:"%n - RemoteBox" /v:%h:%p'},
                           {num => 2, desc => 'FreeRDP (Old Syntax)',       command => 'xfreerdp -g %Xx%Y --plugin cliprdr --plugin rdpsnd -T "%n - RemoteBox" %h:%p'},
-                          {num => 3, desc => 'Rdesktop',                   command => 'rdesktop -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'},
+                          {num => 3, desc => 'Rdesktop',                   command => 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'},
                           {num => 4, desc => 'KRDC',                       command => 'krdc rdp://%h:%p'},
                           {num => 5, desc => 'Windows RDP Client (mstsc)', command => 'mstsc /w:%X /h:%Y /v:%h:%p'});
 
@@ -297,13 +300,6 @@ sub rsplitpath {
     else { return File::Spec::Win32->splitpath(@_); }
 }
 
-# Callback set on a timer to attempt to keep the connection alive in the
-# case where a timeout is set on the server. This callback needs to be cheap
-sub heartbeat {
-    IVirtualBox_getVersion($gui{websn}) if ($gui{websn});
-    return 1; # Return 1 to stop the timer from being removed
-}
-
 sub secs_to_humantime {
     my ($time) = @_;
     my $hours = int($time / 3600);
@@ -367,4 +363,10 @@ sub xor_pass {
     return $encpass;
 }
 
+sub strim {
+    my ($str) = @_;
+    $str =~ s/^\s+|\s+$//g;
+    return $str;
+}
+
 1;
