@@ -6,10 +6,10 @@ use File::Spec::Functions;
 use File::Spec::Win32;
 use File::Spec::Unix;
 use Getopt::Std;
-use Gtk2 '-init';
+use Gtk3 -init;
 our $sharedir;
 
-my $builder = Gtk2::Builder->new;
+my $builder = Gtk3::Builder->new;
 $builder->add_from_file("$sharedir/remotebox.xml");
 $builder->connect_signals();
 
@@ -30,98 +30,98 @@ our %gui = (textbufferEditGenDescription         => $builder->get_object('textbu
             websn                                => undef);
 
 # Guest Status
-$gui{img}{Aborted} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Aborted.png");
-$gui{img}{DeletingSnapshot} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{DeletingSnapshotOnline} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{DeletingSnapshotPaused} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{Discarding} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Discarding.png");
-$gui{img}{Error} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Error.png");
-$gui{img}{FaultTolerantSyncing} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{FirstOnline} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
-$gui{img}{FirstTransient} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
-$gui{img}{LastOnline} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
-$gui{img}{LastTransient} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
-$gui{img}{LiveSnapshotting} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{OnlineSnapshotting} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{Paused} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Paused.png");
-$gui{img}{PoweredOff} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/PoweredOff.png");
-$gui{img}{Restoring} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Restoring.png");
-$gui{img}{RestoringSnapshot} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Restoring.png");
-$gui{img}{Running} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
-$gui{img}{Saved} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Saved.png");
-$gui{img}{Saving} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Saving.png");
-$gui{img}{SettingUp} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
-$gui{img}{Snapshotting} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{Starting} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
-$gui{img}{Stopping} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{Stuck} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Stuck.png");
-$gui{img}{Teleported} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/PoweredOff.png");
-$gui{img}{Teleporting} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{TeleportingIn} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
-$gui{img}{TeleportingPausedVM} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Paused.png");
+$gui{img}{Aborted} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Aborted.png");
+$gui{img}{DeletingSnapshot} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{DeletingSnapshotOnline} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{DeletingSnapshotPaused} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{Discarding} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Discarding.png");
+$gui{img}{Error} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Error.png");
+$gui{img}{FaultTolerantSyncing} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{FirstOnline} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
+$gui{img}{FirstTransient} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
+$gui{img}{LastOnline} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
+$gui{img}{LastTransient} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
+$gui{img}{LiveSnapshotting} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{OnlineSnapshotting} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{Paused} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Paused.png");
+$gui{img}{PoweredOff} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/PoweredOff.png");
+$gui{img}{Restoring} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Restoring.png");
+$gui{img}{RestoringSnapshot} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Restoring.png");
+$gui{img}{Running} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
+$gui{img}{Saved} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Saved.png");
+$gui{img}{Saving} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Saving.png");
+$gui{img}{SettingUp} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
+$gui{img}{Snapshotting} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{Starting} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Running.png");
+$gui{img}{Stopping} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{Stuck} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Stuck.png");
+$gui{img}{Teleported} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/PoweredOff.png");
+$gui{img}{Teleporting} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{TeleportingIn} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Misc.png");
+$gui{img}{TeleportingPausedVM} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/gueststatus/Paused.png");
 # Storage Icons
-$gui{img}{Network} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/nw_16px.png");
-$gui{img}{HardDisk} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/hd_16px.png");
-$gui{img}{DVD} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/cd_16px.png");
-$gui{img}{Floppy} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/fd_16px.png");
-$gui{img}{ctr}{IDE} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/ide_16px.png");
-$gui{img}{ctr}{SATA} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/sata_16px.png");
+$gui{img}{Network} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/nw_16px.png");
+$gui{img}{HardDisk} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/hd_16px.png");
+$gui{img}{DVD} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/cd_16px.png");
+$gui{img}{Floppy} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/fd_16px.png");
+$gui{img}{ctr}{IDE} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/ide_16px.png");
+$gui{img}{ctr}{SATA} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/sata_16px.png");
 $gui{img}{ctr}{SAS} = $gui{img}{ctr}{SATA};
-$gui{img}{ctr}{SCSI} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/scsi_16px.png");
-$gui{img}{ctr}{Floppy} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/floppy_16px.png");
-$gui{img}{ctr}{USB} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/usb_16px.png");
-$gui{img}{ctr}{PCIe} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/nvme_16px.png");
-$gui{img}{ctr}{VirtioSCSI} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/virtio_scsi_16px.png");
+$gui{img}{ctr}{SCSI} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/scsi_16px.png");
+$gui{img}{ctr}{Floppy} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/floppy_16px.png");
+$gui{img}{ctr}{USB} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/usb_16px.png");
+$gui{img}{ctr}{PCIe} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/nvme_16px.png");
+$gui{img}{ctr}{VirtioSCSI} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/virtio_scsi_16px.png");
 # Snapshot icons
-$gui{img}{SnapshotOffline} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/snapshot_offline_16px.png");
-$gui{img}{SnapshotOnline} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/snapshot_online_16px.png");
-$gui{img}{SnapshotCurrent} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/machine_16px.png");
+$gui{img}{SnapshotOffline} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/snapshot_offline_16px.png");
+$gui{img}{SnapshotOnline} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/snapshot_online_16px.png");
+$gui{img}{SnapshotCurrent} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/machine_16px.png");
 # OS Icons
-$gui{img}{OtherOS} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/Other.png");
-$gui{img}{OtherOS64} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/Other_64.png");
+$gui{img}{OtherOS} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/Other.png");
+$gui{img}{OtherOS64} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/os/Other_64.png");
 # Other Icons
-$gui{img}{VMGroup} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/vm_group_16px.png");
-$gui{img}{DirIcon} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/sf_16px.png");
-$gui{img}{FileIcon} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/vm_open_filemanager_16px.png");
-$gui{img}{ParentIcon} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/sf_parent_16px.png");
+$gui{img}{VMGroup} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/vm_group_16px.png");
+$gui{img}{DirIcon} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/sf_16px.png");
+$gui{img}{FileIcon} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/vm_open_filemanager_16px.png");
+$gui{img}{ParentIcon} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/sf_parent_16px.png");
 # Details Icons
-$gui{img}{CatGen} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/machine_16px.png");
-$gui{img}{CatSys} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/chipset_16px.png");
-$gui{img}{CatDisp} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/vrdp_16px.png");
-$gui{img}{CatStor} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/hd_16px.png");
-$gui{img}{CatAudio} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/sound_16px.png");
-$gui{img}{CatNet} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/nw_16px.png");
-$gui{img}{CatIO} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/serial_port_16px.png");
-$gui{img}{CatUSB} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/usb_16px.png");
-$gui{img}{CatShare} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/sf_16px.png");
-$gui{img}{CatDesc} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/description_16px.png");
+$gui{img}{CatGen} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/machine_16px.png");
+$gui{img}{CatSys} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/chipset_16px.png");
+$gui{img}{CatDisp} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/vrdp_16px.png");
+$gui{img}{CatStor} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/hd_16px.png");
+$gui{img}{CatAudio} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/sound_16px.png");
+$gui{img}{CatNet} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/nw_16px.png");
+$gui{img}{CatIO} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/serial_port_16px.png");
+$gui{img}{CatUSB} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/usb_16px.png");
+$gui{img}{CatShare} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/sf_16px.png");
+$gui{img}{CatDesc} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/description_16px.png");
 # Progress Decals
-$gui{img}{ProgressClone} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_clone_90px.png");
-$gui{img}{ProgressRefresh} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_refresh_90px.png");
-$gui{img}{ProgressDelete} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_delete_90px.png");
-$gui{img}{ProgressExport} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_export_90px.png");
-$gui{img}{ProgressImport} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_import_90px.png");
-$gui{img}{ProgressInstallGA} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_install_guest_additions_90px.png");
-$gui{img}{ProgressMediaCreate} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_media_create_90px.png");
-$gui{img}{ProgressMediaDelete} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_media_delete_90px.png");
-$gui{img}{ProgressMediaMove} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_media_move_90px.png");
-$gui{img}{ProgressMediaResize} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_media_resize_90px.png");
-$gui{img}{ProgressNetwork} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_network_interface_90px.png");
-$gui{img}{ProgressPowerOff} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_poweroff_90px.png");
-$gui{img}{ProgressReadAppl} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_reading_appliance_90px.png");
-$gui{img}{ProgressSettings} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_settings_90px.png");
-$gui{img}{ProgressSnapshotCreate} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_snapshot_create_90px.png");
-$gui{img}{ProgressSnapshotDiscard} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_snapshot_discard_90px.png");
-$gui{img}{ProgressSnapshotRestore} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_snapshot_restore_90px.png");
-$gui{img}{ProgressStart} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_start_90px.png");
-$gui{img}{ProgressRestore} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_state_restore_90px.png");
-$gui{img}{ProgressStateSave} = Gtk2::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_state_save_90px.png");
+$gui{img}{ProgressClone} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_clone_90px.png");
+$gui{img}{ProgressRefresh} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_refresh_90px.png");
+$gui{img}{ProgressDelete} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_delete_90px.png");
+$gui{img}{ProgressExport} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_export_90px.png");
+$gui{img}{ProgressImport} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_import_90px.png");
+$gui{img}{ProgressInstallGA} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_install_guest_additions_90px.png");
+$gui{img}{ProgressMediaCreate} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_media_create_90px.png");
+$gui{img}{ProgressMediaDelete} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_media_delete_90px.png");
+$gui{img}{ProgressMediaMove} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_media_move_90px.png");
+$gui{img}{ProgressMediaResize} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_media_resize_90px.png");
+$gui{img}{ProgressNetwork} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_network_interface_90px.png");
+$gui{img}{ProgressPowerOff} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_poweroff_90px.png");
+$gui{img}{ProgressReadAppl} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_reading_appliance_90px.png");
+$gui{img}{ProgressSettings} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_settings_90px.png");
+$gui{img}{ProgressSnapshotCreate} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_snapshot_create_90px.png");
+$gui{img}{ProgressSnapshotDiscard} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_snapshot_discard_90px.png");
+$gui{img}{ProgressSnapshotRestore} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_snapshot_restore_90px.png");
+$gui{img}{ProgressStart} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_start_90px.png");
+$gui{img}{ProgressRestore} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_state_restore_90px.png");
+$gui{img}{ProgressStateSave} = Gtk3::Gdk::Pixbuf->new_from_file("$sharedir/icons/progress_state_save_90px.png");
 our %prefs;
 
 # Fill %gui so we can reference them easily.
 foreach ($builder->get_objects) {
     my $id;
-    eval{ $id = $_->Gtk2::Buildable::get_name; }; # DONT USE $_->get_name()
+    eval{ $id = $_->Gtk3::Buildable::get_name; }; # DONT USE $_->get_name()
     $gui{$id} = $_ if ($id);
 }
 
@@ -135,14 +135,30 @@ our %signal = (fam                => $gui{comboboxNewOSFam}->signal_connect(chan
                audioctr           => $gui{comboboxEditAudioCtr}->signal_connect(changed => \&audio_ctr),
                audiocodec         => $gui{comboboxEditAudioCodec}->signal_connect(changed => \&audio_codec),
                netadaptype        => $gui{comboboxEditNetType}->signal_connect(changed => \&net_adapter_type, $gui{checkbuttonEditNetEnable}),
-               netattach          => $gui{comboboxEditNetAttach}->signal_connect(changed => \&net_attach, $gui{checkbuttonEditNetEnable}),
+               comboboxEditNetAttach_changed          => $gui{comboboxEditNetAttach}->signal_connect(changed => \&net_attach, $gui{checkbuttonEditNetEnable}),
                netname            => $gui{comboboxEditNetName}->signal_connect(changed => \&net_name, $gui{checkbuttonEditNetEnable}),
                genericdrv         => $gui{comboboxentryEditNetGenDriver}->signal_connect(changed => \&net_generic_driver, $gui{checkbuttonEditNetEnable}),
                nameint            => $gui{comboboxentryEditNetNameInt}->signal_connect(changed => \&net_name_internal, $gui{checkbuttonEditNetEnable}),
                stortype           => $gui{comboboxEditStorCtrType}->signal_connect(changed => \&storage_ctr_type),
                usbtoggle          => $gui{checkbuttonEditUSBEnable}->signal_connect(toggled => \&usb_toggle),
                snapfolderactivate => $gui{entryEditGenSnapFolder}->signal_connect(activate => \&gen_snapfolder),
-               snapfolderfocus    => $gui{entryEditGenSnapFolder}->signal_connect(activate => \&gen_snapfolder));
+               snapfolderfocus    => $gui{entryEditGenSnapFolder}->signal_connect(activate => \&gen_snapfolder),
+               treeviewGuest_cursorChanged => $gui{treeviewGuest}->signal_connect('cursor-changed' => \&onsel_list_guest),
+               treeviewSnapshots_cursorChanged => $gui{treeviewSnapshots}->signal_connect('cursor-changed' => \&onsel_list_snapshots),
+               treeviewPFRulesIPv4_cursorChanged => $gui{treeviewPFRulesIPv4}->signal_connect('cursor-changed' => \&onsel_list_pf4),
+               treeviewPFRulesIPv6_cursorChanged => $gui{treeviewPFRulesIPv6}->signal_connect('cursor-changed' => \&onsel_list_pf6),
+               treeviewVMMHD_cursorChanged => $gui{treeviewVMMHD}->signal_connect('cursor-changed' => \&onsel_list_vmmhd),
+               treeviewVMMDVD_cursorChanged => $gui{treeviewVMMDVD}->signal_connect('cursor-changed' => \&onsel_list_vmmdvd),
+               treeviewVMMFloppy_cursorChanged => $gui{treeviewVMMFloppy}->signal_connect('cursor-changed' => \&onsel_list_vmmfloppy),
+               treeviewRemoteFileChooser_cursorChanged => $gui{treeviewRemoteFileChooser}->signal_connect('cursor-changed' => \&onsel_list_remotefiles_single),
+               treeviewConnectionProfiles_cursorChanged => $gui{treeviewConnectionProfiles}->signal_connect('cursor-changed' => \&onsel_list_profile),
+               treeviewEditSysBoot_cursorChanged1 => $gui{treeviewEditSysBoot}->signal_connect('cursor-changed' => \&sys_mother_boot_order),
+               treeviewEditSysBoot_cursorChanged2 => $gui{treeviewEditSysBoot}->signal_connect('cursor-changed' => \&sys_mother_sens_boot_sel),
+               treeviewEditUSBFilters_cursorChanged => $gui{treeviewEditUSBFilters}->signal_connect('cursor-changed' => \&onsel_list_usbfilters),
+               treeviewEditShared_cursorChanged => $gui{treeviewEditShared}->signal_connect('cursor-changed' => \&onsel_list_shared),
+               treeviewEditStor_cursorChanged => $gui{treeviewEditStor}->signal_connect('cursor-changed' => \&onsel_list_editstorage),
+               treeviewVBPrefsHON_cursorChanged => $gui{treeviewVBPrefsHON}->signal_connect('cursor-changed' => \&onsel_list_vbprefshon),
+               treeviewVBPrefsNAT_cursorChanged => $gui{treeviewVBPrefsNAT}->signal_connect('cursor-changed' => \&onsel_list_vbprefsnat));
 
 # Work around a bug in Glade that disables toolbutton menus
 $gui{toolbuttonStop}->set_menu($gui{menuStop});
@@ -154,7 +170,7 @@ $gui{treeviewInfo}->get_selection->set_mode('GTK_SELECTION_NONE');
 # Populate the submenu for the screensize video hinting
 my $scr_res_tbl = &get_scr_res_tbl();
 foreach my $res (@{$scr_res_tbl}) {
-    $gui{'menuitemSetVideo' . "$$res{w}_$$res{h}"} = Gtk2::MenuItem->new_with_label($$res{w} . 'x' . $$res{h} . ":32 ($$res{aspx}:$$res{aspy})");
+    $gui{'menuitemSetVideo' . "$$res{w}_$$res{h}"} = Gtk3::MenuItem->new_with_label($$res{w} . 'x' . $$res{h} . ":32 ($$res{aspx}:$$res{aspy})");
     $gui{'menuitemSetVideo' . "$$res{w}_$$res{h}"}->signal_connect(activate => \&send_video_hint, [$$res{w}, $$res{h}, 32]);
     $gui{'menuitemSetVideo' . "$$res{w}_$$res{h}"}->show();
     $gui{'menuitemSetVideo' . "$$res{w}_$$res{h}"}->set_tooltip_text('Requires a minimum of ' . &vram_needed($$res{w}, $$res{h}, 32) . 'MB of video memory assigned to the guest');
@@ -165,13 +181,13 @@ foreach my $res (@{$scr_res_tbl}) {
 my $fsiter;
 foreach my $res (@{$scr_res_tbl}) {
     $fsiter = $gui{liststoreDispCaptureSize}->append;
-    $gui{liststoreDispCaptureSize}->set($fsiter, 0, "$$res{w}x$$res{h} ($$res{aspx}:$$res{aspy})", 1, $$res{w}, 2, $$res{h});
+    $gui{liststoreDispCaptureSize}->set($fsiter, [0, 1, 2], ["$$res{w}x$$res{h} ($$res{aspx}:$$res{aspy})", $$res{w}, $$res{h}]);
 }
 
 # Populate the keyboard sequence menus
 my $cafx_code_tbl = &get_cafx_code_tbl();
 foreach my $code (@{$cafx_code_tbl}) {
-    $gui{'menuitemKeyboard' . $$code{desc}} = Gtk2::MenuItem->new_with_label($$code{desc});
+    $gui{'menuitemKeyboard' . $$code{desc}} = Gtk3::MenuItem->new_with_label($$code{desc});
     $gui{'menuitemKeyboard' . $$code{desc}}->signal_connect(activate => \&keyboard_send, $code);
     $gui{'menuitemKeyboard' . $$code{desc}}->show();
     $gui{menuKeyboardCAF}->append($gui{'menuitemKeyboard' . $$code{desc}});
@@ -179,30 +195,30 @@ foreach my $code (@{$cafx_code_tbl}) {
 
 my $asfx_code_tbl = &get_asfx_code_tbl();
 foreach my $code (@{$asfx_code_tbl}) {
-    $gui{'menuitemKeyboard' . $$code{desc}} = Gtk2::MenuItem->new_with_label($$code{desc});
+    $gui{'menuitemKeyboard' . $$code{desc}} = Gtk3::MenuItem->new_with_label($$code{desc});
     $gui{'menuitemKeyboard' . $$code{desc}}->signal_connect(activate => \&keyboard_send, $code);
     $gui{'menuitemKeyboard' . $$code{desc}}->show();
     $gui{menuKeyboardASF}->append($gui{'menuitemKeyboard' . $$code{desc}});
 }
 
-$gui{menuitemKeyboardCAD} = Gtk2::MenuItem->new_with_label('Ctrl-Alt-Delete');
+$gui{menuitemKeyboardCAD} = Gtk3::MenuItem->new_with_label('Ctrl-Alt-Delete');
 $gui{menuitemKeyboardCAD}->signal_connect(activate => \&keyboard_CAD);
 $gui{menuitemKeyboardCAD}->show();
 $gui{menuKeyboard}->append($gui{menuitemKeyboardCAD});
 
 my $misc_code_tbl = &get_misc_code_tbl();
 foreach my $code (@{$misc_code_tbl}) {
-    $gui{'menuitemKeyboard' . $$code{desc}} = Gtk2::MenuItem->new_with_label($$code{desc});
+    $gui{'menuitemKeyboard' . $$code{desc}} = Gtk3::MenuItem->new_with_label($$code{desc});
     $gui{'menuitemKeyboard' . $$code{desc}}->signal_connect(activate => \&keyboard_send, $code);
     $gui{'menuitemKeyboard' . $$code{desc}}->show();
     $gui{menuKeyboard}->append($gui{'menuitemKeyboard' . $$code{desc}});
-    $gui{'menuitemKeyboardMini' . $$code{desc}} = Gtk2::MenuItem->new_with_label($$code{desc});
+    $gui{'menuitemKeyboardMini' . $$code{desc}} = Gtk3::MenuItem->new_with_label($$code{desc});
     $gui{'menuitemKeyboardMini' . $$code{desc}}->signal_connect(activate => \&keyboard_send, $code);
     $gui{'menuitemKeyboardMini' . $$code{desc}}->show();
     $gui{menuKeyboardMini}->append($gui{'menuitemKeyboardMini' . $$code{desc}});
 }
 
-$gui{menuitemKeyboardRK} = Gtk2::MenuItem->new_with_label('Release Keys');
+$gui{menuitemKeyboardRK} = Gtk3::MenuItem->new_with_label('Release Keys');
 $gui{menuitemKeyboardRK}->signal_connect(activate => \&keyboard_releasekeys);
 $gui{menuitemKeyboardRK}->show();
 $gui{menuKeyboard}->append($gui{menuitemKeyboardRK});
@@ -210,7 +226,7 @@ $gui{menuKeyboard}->append($gui{menuitemKeyboardRK});
 # Populate RDP/VNC preset menus
 my $rdp_preset_tbl = &get_rdp_preset_tbl();
 foreach my $preset (@{$rdp_preset_tbl}) {
-    $gui{'menuitemRDPPreset' . $$preset{num}} = Gtk2::MenuItem->new_with_label($$preset{desc});
+    $gui{'menuitemRDPPreset' . $$preset{num}} = Gtk3::MenuItem->new_with_label($$preset{desc});
     $gui{'menuitemRDPPreset' . $$preset{num}}->signal_connect(activate => \&set_rdppreset, $$preset{command});
     $gui{'menuitemRDPPreset' . $$preset{num}}->show();
     $gui{menuRDPPreset}->append($gui{'menuitemRDPPreset' . $$preset{num}});
@@ -218,12 +234,15 @@ foreach my $preset (@{$rdp_preset_tbl}) {
 
 my $vnc_preset_tbl = &get_vnc_preset_tbl();
 foreach my $preset (@{$vnc_preset_tbl}) {
-    $gui{'menuitemVNCPreset' . $$preset{num}} = Gtk2::MenuItem->new_with_label($$preset{desc});
+    $gui{'menuitemVNCPreset' . $$preset{num}} = Gtk3::MenuItem->new_with_label($$preset{desc});
     $gui{'menuitemVNCPreset' . $$preset{num}}->signal_connect(activate => \&set_vncpreset, $$preset{command});
     $gui{'menuitemVNCPreset' . $$preset{num}}->show();
     $gui{menuVNCPreset}->append($gui{'menuitemVNCPreset' . $$preset{num}});
 }
 
+
+
+
 # Transient Window Handling
 # A window's transient is automatically set on open
 {
@@ -250,20 +269,22 @@ foreach my $preset (@{$vnc_preset_tbl}) {
 # Ghosts window and optionally sets pointer
 sub busy_window {
     my ($window, $sens, $pointer) = @_;
+    my $gdkwindow = $window->get_window();
     $window->set_sensitive($sens);
-
-    if ($pointer) { eval { $window->window->set_cursor(Gtk2::Gdk::Cursor->new($pointer)); }; }
-    else { eval{ $window->window->set_cursor(undef); }; }
-
-    Gtk2->main_iteration() while Gtk2->events_pending();
+    &set_pointer($window, $pointer);
 }
 
-# Busy the pointer only
-sub busy_pointer {
+# Set's the style of the mouse pointer
+sub set_pointer {
     my ($window, $pointer) = @_;
-    if ($pointer) { eval { $window->window->set_cursor(Gtk2::Gdk::Cursor->new('watch')); }; }
-    else { eval{ $window->window->set_cursor(undef); }; }
-    Gtk2->main_iteration() while Gtk2->events_pending();
+    my $gdkwindow = $window->get_window();
+
+    # If the window is no visible, gdkwindow is empty, so check.
+    if ($gdkwindow) {
+        if ($pointer) { $gdkwindow->set_cursor(Gtk3::Gdk::Cursor->new($pointer)); }
+        else {$gdkwindow->set_cursor(undef); }
+    }
+    Gtk3::main_iteration while Gtk3::events_pending;
 }
 
 sub handle_bioslogofilechooser {
@@ -577,6 +598,7 @@ sub show_mediummovefilechooser {
                                     handler   => \&handle_movemediumfilechooser});
 }
 
+# Shows the dialog for choosing files on the server
 sub show_remotefilechooser_window {
     my ($param) = @_;
     my $vhost = &vhost();
@@ -610,19 +632,27 @@ sub show_remotefilechooser_window {
     if ($response eq 'ok') {
         my $location = $gui{entryRemoteFileChooserLocation}->get_text();
         my $filename = $gui{entryRemoteFileChooserFile}->get_text();
-        if ($$param{mode} eq 'file') { &{$$param{handler}}($location, $filename) }
+
+        if ($$param{mode} eq 'file') {
+            &{$$param{handler}}($location, $filename)
+        }
         else {
             my $filearrayref;
             $filearrayref = &getsel_list_remotefiles();
-            &{$$param{handler}}($location, $filearrayref);
+            &{$$param{handler}}($location, $filearrayref); # Execute the handler
         }
+
     }
 
     return $gui{entryRemoteFileChooserLocation}->get_text();
 }
 
-sub refresh_remotefilechooser { &fill_list_remotefiles($gui{entryRemoteFileChooserLocation}->get_text(), $gui{entryRemoteFileChooserFilter}->get_text()); }
+# Refreshes the contents of the file chooser
+sub refresh_remotefilechooser {
+    &fill_list_remotefiles($gui{entryRemoteFileChooserLocation}->get_text(), $gui{entryRemoteFileChooserFilter}->get_text());
+}
 
+# Moves to the parent directory in the file chooser
 sub cdup_remotefilechooser {
     IVFSExplorer_cdUp($gui{IVFSExplorer});
     &fill_list_remotefiles(IVFSExplorer_getPath($gui{IVFSExplorer}), $gui{entryRemoteFileChooserFilter}->get_text());
@@ -639,7 +669,7 @@ sub show_progress_window {
     $gui{progressbar}->set_text(''); # Reset text so its not cached from a previous call
     $gui{progressbar}->set_fraction(0); # Reset fraction back to 0
     (IProgress_getCancelable($IProgress) eq 'true') ? $gui{buttonProgressCancel}->show() : $gui{buttonProgressCancel}->hide();
-    Gtk2->main_iteration() while Gtk2->events_pending();
+    Gtk3::main_iteration while Gtk3::events_pending;
 
     $timer = Glib::Timeout->add(1000,
         sub {
@@ -672,7 +702,7 @@ sub show_progress_window {
     $gui{dialogProgress}->hide();
     Glib::Source->remove($timer) if ($timer);
     IProgress_cancel($IProgress) if ($response ne 'ok');
-    Gtk2->main_iteration() while Gtk2->events_pending();
+    Gtk3::main_iteration while Gtk3::events_pending;
     return $resultcode;
 }
 
@@ -764,16 +794,16 @@ sub spinbox_bytes_out {
     my $adjval = int($adjustment->get_value());
 
     if ($adjval < 1024) {
-        $adjustment->step_increment(1.00);
+        $adjustment->set_step_increment(1.00);
         $txt = "$adjval MB";
     }
     elsif ($adjval < 1048576) {
-        $adjustment->step_increment(10.25);
+        $adjustment->set_step_increment(10.25);
         $adjval /= 1024;
         $txt = sprintf('%0.2f GB', $adjval);
     }
     else {
-        $adjustment->step_increment(10486);
+        $adjustment->set_step_increment(10486);
         $adjval /= 1048576;
         $txt = sprintf('%0.2f TB', $adjval);
     }
@@ -841,16 +871,16 @@ sub spinbox_time_out {
     my $adjval = int($adjustment->get_value());
 
     if ($adjval < 1000) {
-        $adjustment->step_increment(1.00);
+        $adjustment->set_step_increment(1.00);
         $txt = "$adjval ms";
     }
     elsif ($adjval < 60000) {
-        $adjustment->step_increment(10.00);
+        $adjustment->set_step_increment(10.00);
         $adjval /= 1000;
         $txt = sprintf('%0.2f secs', $adjval);
     }
     else {
-        $adjustment->step_increment(600.00);
+        $adjustment->set_step_increment(600.00);
         $adjval /= 60000;
         $txt = sprintf('%0.2f mins', $adjval);
     }
