@@ -26,9 +26,8 @@ USAGE
 }
 elsif ($cmdopts{H}) { &show_dialog_connect('CMDAUTO'); } # Command line parameter based login
 elsif ($prefs{AUTOCONNPROF}) { &show_dialog_connect('PROFAUTO'); } # Profile based automatic login
-
 $0 = 'RemoteBox VirtualBox Client';
-Gtk2->main;
+Gtk3->main;
 
 sub quit_remotebox {
     &save_window_pos('windowMain'); # Also saves the main preferences
@@ -41,7 +40,7 @@ sub quit_remotebox {
     $gui{menuitemFloppy}->set_submenu($gui{menutmp1});
     $gui{menuitemDVD}->set_submenu($gui{menutmp2});
     $gui{menuitemUSB}->set_submenu($gui{menutmp3});
-    Gtk2->main_quit;
+    Gtk3->main_quit;
 }
 
 # Attempts to logon or fails with a dialog
@@ -52,10 +51,11 @@ sub virtualbox_logon {
     $fault = \&vboxlogonerror;
     $gui{websn} = IWebsessionManager_logon($user, $password);
 
+    # Register timer events and run them immediately if needed.
     if ($gui{websn}) {
         $fault = \&vboxerror; # Install the fault capture
-        $gui{heartbeat} = Glib::Timeout->add(58000, \&heartbeat) if ($prefs{HEARTBEAT}); # Install heartbeat if requested
-        $gui{servermem} = Glib::Timeout->add(300000, \&update_server_membar);
+        $gui{servermem} = Glib::Timeout->add(58000, \&update_server_membar);
+        &update_server_membar();
         return 1;
     }
 }
@@ -64,12 +64,14 @@ sub virtualbox_logon {
 sub virtualbox_logoff {
     my ($closewin) = @_;
     $fault = sub{}; # Disable fault capture. Protection against infinite loops
-    Glib::Source->remove($gui{heartbeat}) if ($gui{heartbeat}); # Remove any heartbeat timers
+
+    # Remove timers
+    Glib::Source->remove($gui{servermem}) if ($gui{servermem});
 
     # Force close any open windows - usually because we've hit a fault. This will cause them to
     # execute their cancel operations
     if ($closewin) {
-        foreach my $win (Gtk2::Window->list_toplevels()) {
+        foreach my $win (Gtk3::Window->list_toplevels()) {
             next if ($win eq $gui{windowMain});
             $win->hide;
         }
@@ -149,8 +151,8 @@ sub show_dialog_connect {
     $gui{dialogConnect}->get_display->flush;
 
     if ($response eq 'ok') {
-        my $url = $gui{entryConnectURL}->get_text();
-        my $user = $gui{entryConnectUser}->get_text();
+        my $url = &strim($gui{entryConnectURL}->get_text());
+        my $user = &strim($gui{entryConnectUser}->get_text());
         $url = $endpoint if (!$url);
         $url =~ s/(\/)+$//g; # Remove all trailing
         $url = "http://$url" if ($url !~ m/^.+:\/\//);
@@ -240,7 +242,7 @@ sub log_save {
     my $logfile = $gui{filechooserLog}->get_filename();
 
     if ($response eq 'ok' and $logfile) {
-        &busy_pointer($gui{dialogLog}, 1);
+        &set_pointer($gui{dialogLog}, 'watch');
         my $log;
         my $offset = 0;
         &addrow_log("Attempting to save guest log $logfile");
@@ -267,7 +269,7 @@ sub log_save {
         }
         else { &show_err_msg('logempty'); }
 
-        &busy_pointer($gui{dialogLog}, 0);
+        &set_pointer($gui{dialogLog});
     }
 }
 
@@ -309,9 +311,14 @@ sub show_dialog_exportappl {
         my $response = $gui{dialogExportAppl}->run;
 
         if ($response eq 'ok') {
+
             # Other entries don't required validation
-            if (!$gui{entryExportApplFile}->get_text()) { &show_err_msg('invalidfile'); }
-            elsif (!$gui{entryExportApplName}->get_text()) { &show_err_msg('invalidname'); }
+            if (!$gui{entryExportApplFile}->get_text()) {
+                &show_err_msg('invalidfile');
+            }
+            elsif (!$gui{entryExportApplName}->get_text()) {
+                &show_err_msg('invalidname');
+            }
             else {
                 $gui{dialogExportAppl}->hide;
                 my $location = $gui{entryExportApplFile}->get_text() . &getsel_combo($gui{comboboxExportApplFormat}, 2);
@@ -335,7 +342,7 @@ sub show_dialog_exportappl {
                 $iter_e = $gui{textbufferExportApplLicense}->get_end_iter();
                 IVirtualSystemDescription_addDescription($IVirtualSystemDescription, 'License', $gui{textbufferExportApplLicense}->get_text($iter_s, $iter_e, 0), '');
                 # The export options array is not at the end of the function so we have to make it a fixed size. In this case 3 elements.
-                # We also cannot pass a null option, so choose something harmless and duplicate (CreateManifest). Messy but not way around it...
+                # We also cannot pass a null option, so choose something harmless and duplicate (CreateManifest). Messy but no way around it...
                 my @exportopts = ('CreateManifest', 'CreateManifest', 'CreateManifest');
                 $exportopts[1] = 'ExportDVDImages' if ($gui{checkbuttonExportApplISO}->get_active() == 1);
                 $exportopts[2] = 'StripAllNonNATMACs' if ($gui{comboboxExportApplMAC}->get_active() == 1);
@@ -347,7 +354,7 @@ sub show_dialog_exportappl {
         }
         else { $gui{dialogExportAppl}->hide; }
 
-    } until (!$gui{dialogExportAppl}->visible());
+    } until (!$gui{dialogExportAppl}->get_visible());
 }
 
 sub show_dialog_snapshotdetails {
@@ -643,7 +650,7 @@ sub take_snapshot {
     &fill_list_guest(); # This also refreshes the snapshot list
 }
 
-# Attempts to open the remote display by calling the RDP client
+# Attempts to open the remote display by calling the RDP/VNC client
 sub open_remote_display {
     my $vhost = &vhost();
     my $gref = &getsel_list_guest();
@@ -651,20 +658,28 @@ sub open_remote_display {
 
     if ($$sref{Lock} eq 'Shared') {
         my $IConsole = ISession_getConsole($$sref{ISession});
+        my $IVRDEServer = IMachine_getVRDEServer($$gref{IMachine});
+        my $bindaddress = &strim(IVRDEServer_getVRDEProperty($IVRDEServer, 'TCP/Address'));
         my $IVRDEServerInfo = IConsole_getVRDEServerInfo($IConsole);
 
         for (1..5) { # Wait up to 5 seconds for the VRDE server to start
             last if ($$IVRDEServerInfo{port} != -1);
+            &addrow_log('Waiting for RDP/VNC service to be available...');
             $IVRDEServerInfo = IConsole_getVRDEServerInfo($IConsole);
             sleep 1;
         }
 
         if ($$IVRDEServerInfo{port} > 0) {
-            my $dispcmd = $prefs{RDPCLIENT};
-            $dispcmd = $prefs{VNCCLIENT} if ($$vhost{vrdeextpack} =~ m/vnc/i);
 
+            if ($prefs{AUTOHINTDISP}) {
+                IDisplay_setVideoModeHint(IConsole_getDisplay($IConsole), 0, 1, 0, 0, 0, $prefs{AUTOHINTDISPX}, $prefs{AUTOHINTDISPY}, $prefs{AUTOHINTDISPD});
+                &addrow_log("Sent video hint ($prefs{AUTOHINTDISPX}x$prefs{AUTOHINTDISPY}:$prefs{AUTOHINTDISPD}) to $$gref{Name}.");
+            }
+
+            # If there's a specific bind address for the guest use that
+            my $dst = $bindaddress ? $bindaddress : $endpoint;
+            my $dispcmd = ($$vhost{vrdeextpack} =~ m/vnc/i) ? $prefs{VNCCLIENT} : $prefs{RDPCLIENT};
             my ($user, $pass) = ($gui{entryConnectUser}->get_text(), $gui{entryConnectPassword}->get_text());
-            my $dst = $endpoint;
             $dst =~ s/^.*:\/\///;
             $dst =~ s/:\d+$//;
             $dispcmd =~ s/%h/$dst/g;
@@ -676,17 +691,10 @@ sub open_remote_display {
             $dispcmd =~ s/%X/$prefs{AUTOHINTDISPX}/g;
             $dispcmd =~ s/%Y/$prefs{AUTOHINTDISPY}/g;
             $dispcmd =~ s/%D/$prefs{AUTOHINTDISPD}/g;
-
-            if ($prefs{AUTOHINTDISP}) {
-                my $IConsole = ISession_getConsole($$sref{ISession});
-                IDisplay_setVideoModeHint(IConsole_getDisplay($IConsole), 0, 1, 0, 0, 0, $prefs{AUTOHINTDISPX}, $prefs{AUTOHINTDISPY}, $prefs{AUTOHINTDISPD});
-                &addrow_log("Sent video hint ($prefs{AUTOHINTDISPX}x$prefs{AUTOHINTDISPY}:$prefs{AUTOHINTDISPD}) to $$gref{Name}.");
-            }
-
             ($^O =~ m/MSWin/) ? $dispcmd .= ' >nul' : $dispcmd .= ' &';
+            &addrow_log("Request to open remote display for $$gref{Name} at address $dst:$$IVRDEServerInfo{port} using:");
+            &addrow_log("    $dispcmd");
             system("$dispcmd");
-            &addrow_log("Calling: $dispcmd");
-            &addrow_log("Request to open remote display for $$gref{Name} at address $dst:$$IVRDEServerInfo{port}");
         }
         else { &show_err_msg('remotedisplay', " ($$gref{Name})"); }
     }
@@ -703,10 +711,10 @@ sub show_rmb_menu {
         # This code is needed because if the user just presses the RMB, then GTK has not updated the
         # location of the cursor until AFTER this routine is complete meaning we will be referencing the
         # wrong VM. We need to force a cursor update first.
-        my $path = $gui{treeviewGuest}->get_path_at_pos(int($event->x), int($event->y));
+        my ($path, $col) = $gui{treeviewGuest}->get_path_at_pos(int($event->x), int($event->y));
         if ($path) {
             $gui{treeviewGuest}->grab_focus();
-            $gui{treeviewGuest}->set_cursor($path);
+            $gui{treeviewGuest}->set_cursor($path, undef, 0);
         }
 
         $gui{menuMachine}->popup(undef, undef, undef, undef, 0, $event->time);
@@ -719,33 +727,33 @@ sub show_rmb_menu {
 # Called when parent DVD menu is highlighted. Cheaper than calling each time main menu is opened
 sub fill_menu_dvd {
     my $vhost = &vhost();
-    my $dvdmenu = Gtk2::Menu->new();
+    my $dvdmenu = Gtk3::Menu->new();
     $gui{menuitemDVD}->set_submenu(undef); # Help garbage collection
     $gui{menuitemDVD}->set_submenu($dvdmenu); # Hijack the temporary submenu (restored on exit)
     my $IMediumRef = &get_all_media('DVD');
-    my $item = Gtk2::MenuItem->new_with_label('<Empty Drive>');
+    my $item = Gtk3::MenuItem->new_with_label('<Empty Drive>');
     $dvdmenu->append($item);
     $item->show();
     $item->signal_connect(activate => \&mount_dvd_online, '');
-    my $sep = Gtk2::SeparatorMenuItem->new();
+    my $sep = Gtk3::SeparatorMenuItem->new();
     $dvdmenu->append($sep);
     $sep->show();
 
     if ($$vhost{dvd}) {
         foreach my $pdvd (@{$$vhost{dvd}}) {
-            my $item = Gtk2::MenuItem->new_with_label('<Server Drive> ' . IMedium_getLocation($pdvd));
+            my $item = Gtk3::MenuItem->new_with_label('<Server Drive> ' . IMedium_getLocation($pdvd));
             $dvdmenu->append($item);
             $item->show();
             $item->signal_connect(activate => \&mount_dvd_online, $pdvd);
         }
 
-        my $pdvdsep = Gtk2::SeparatorMenuItem->new();
+        my $pdvdsep = Gtk3::SeparatorMenuItem->new();
         $dvdmenu->append($pdvdsep);
         $pdvdsep->show();
     }
 
     foreach (sort { lc($$IMediumRef{$a}) cmp lc($$IMediumRef{$b}) } (keys %$IMediumRef)) {
-        my $item = Gtk2::MenuItem->new_with_label($$IMediumRef{$_});
+        my $item = Gtk3::MenuItem->new_with_label($$IMediumRef{$_});
         $dvdmenu->append($item);
         $item->show();
         $item->signal_connect(activate => \&mount_dvd_online, $_);
@@ -759,7 +767,7 @@ sub fill_menu_usb {
     my $sref = &get_session($$gref{IMachine});
 
     if ($$sref{Lock} eq 'Shared') {
-        my $usbmenu = Gtk2::Menu->new();
+        my $usbmenu = Gtk3::Menu->new();
         $gui{menuitemUSB}->set_submenu(undef); # Help garbage collection
         $gui{menuitemUSB}->set_submenu($usbmenu); # Hijack the temporary submenu (restored on exit)
         my @IHostUSBDevices = IHost_getUSBDevices(IVirtualBox_getHost($gui{websn}));
@@ -772,7 +780,7 @@ sub fill_menu_usb {
                                         IUSBDevice_getProduct($usb),
                                         sprintf('%04x', IUSBDevice_getRevision($usb)));
 
-            my $item = Gtk2::CheckMenuItem->new_with_label($label);
+            my $item = Gtk3::CheckMenuItem->new_with_label($label);
             my $usbid = IUSBDevice_getId($usb);
             $item->set_active(1) if $connected{$usbid};
             $usbmenu->append($item);
@@ -790,13 +798,13 @@ sub fill_menu_cpu {
     my $sref = &get_session($$gref{IMachine});
 
     if ($$sref{Lock} eq 'Shared') {
-        my $cpumenu = Gtk2::Menu->new();
+        my $cpumenu = Gtk3::Menu->new();
         $gui{menuitemHotPlugCPU}->set_submenu(undef); # Help garbage collection
         $gui{menuitemHotPlugCPU}->set_submenu($cpumenu); # Hijack the temporary submenu (restored on exit)
         my $cpucount = IMachine_getCPUCount($$sref{IMachine});
 
         # CPU 0 is special - it can never be detached.
-        my $item = Gtk2::CheckMenuItem->new_with_label('vCPU 0');
+        my $item = Gtk3::CheckMenuItem->new_with_label('vCPU 0');
         $item->set_active(1);
         $item->set_sensitive(0);
         $item->set_tooltip_text('vCPU 0 is never hot pluggable');
@@ -804,7 +812,7 @@ sub fill_menu_cpu {
         $item->show();
 
         foreach my $cpunum (1..($cpucount - 1)) {
-            my $item = Gtk2::CheckMenuItem->new_with_label("vCPU $cpunum");
+            my $item = Gtk3::CheckMenuItem->new_with_label("vCPU $cpunum");
             $item->set_active(1) if (&bl(IMachine_getCPUStatus($$sref{IMachine}, $cpunum)));
             $cpumenu->append($item);
             $item->show();
@@ -865,33 +873,33 @@ sub mount_usb_online {
 # Called when parent Floppy menu is highlighted. Cheaper than calling each time machine menu is opened
 sub fill_menu_floppy {
     my $vhost = &vhost();
-    my $floppymenu = Gtk2::Menu->new();
+    my $floppymenu = Gtk3::Menu->new();
     $gui{menuitemFloppy}->set_submenu(undef); # Help garbage collection
     $gui{menuitemFloppy}->set_submenu($floppymenu); # Hijack the temporary submenu (restored on exit)
     my $IMediumRef = &get_all_media('Floppy');
-    my $item = Gtk2::MenuItem->new_with_label('<Empty Drive>');
+    my $item = Gtk3::MenuItem->new_with_label('<Empty Drive>');
     $floppymenu->append($item);
     $item->show();
     $item->signal_connect(activate => \&mount_floppy_online, '');
-    my $sep = Gtk2::SeparatorMenuItem->new();
+    my $sep = Gtk3::SeparatorMenuItem->new();
     $floppymenu->append($sep);
     $sep->show();
 
     if ($$vhost{floppy}) {
         foreach my $pfloppy (@{$$vhost{floppy}}) {
-            my $item = Gtk2::MenuItem->new_with_label('<Server Drive> ' . IMedium_getLocation($pfloppy));
+            my $item = Gtk3::MenuItem->new_with_label('<Server Drive> ' . IMedium_getLocation($pfloppy));
             $floppymenu->append($item);
             $item->show();
             $item->signal_connect(activate => \&mount_floppy_online, $pfloppy);
         }
 
-        my $pfloppysep = Gtk2::SeparatorMenuItem->new();
+        my $pfloppysep = Gtk3::SeparatorMenuItem->new();
         $floppymenu->append($pfloppysep);
         $pfloppysep->show();
     }
 
     foreach (sort { lc($$IMediumRef{$a}) cmp lc($$IMediumRef{$b}) } (keys %$IMediumRef)) {
-        my $item = Gtk2::MenuItem->new_with_label($$IMediumRef{$_});
+        my $item = Gtk3::MenuItem->new_with_label($$IMediumRef{$_});
         $floppymenu->append($item);
         $item->show();
         $item->signal_connect(activate => \&mount_floppy_online, $_);
@@ -999,7 +1007,7 @@ sub send_video_hint {
 
     if ($$sref{IMachine}) {
         my $IConsole = ISession_getConsole($$sref{ISession});
-        IDisplay_setVideoModeHint(IConsole_getDisplay($IConsole), 0, 1, 0, 0, 0, $$res[0], $$res[1], $$res[2]);
+        IDisplay_setVideoModeHint(IConsole_getDisplay($IConsole), 0, 1, 0, 0, 0, $$res[0], $$res[1], $$res[2], 1);
         &addrow_log("Sent video hint ($$res[0]x$$res[1]:$$res[2]) to $$gref{Name}");
     }
 
@@ -1262,7 +1270,7 @@ sub show_dialog_importappl {
         }
         else { $gui{dialogImportAppl}->hide; }
 
-    } until (!$gui{dialogImportAppl}->visible());
+    } until (!$gui{dialogImportAppl}->get_visible());
 }
 
 # Displays the dialog for entering a decryption password
@@ -1294,7 +1302,7 @@ sub show_dialog_group {
 
         if ($response eq 'ok') {
             $group = $gui{entrySetGroupGroup}->get_text();
-            $group =~ s/\/+$//; # Remove any traling slashes
+            $group =~ s/\/+$//; # Remove any trailing slashes
             $group = "/$group" if ($group !~ m/^\//);
             IMachine_setGroups($$sref{IMachine}, ($group));
             IMachine_saveSettings($$sref{IMachine});
@@ -1306,8 +1314,9 @@ sub show_dialog_group {
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
 }
 
+# Clears the group for a VM
 sub clear_group {
-    &busy_pointer($gui{windowMain}, 1);
+    &set_pointer($gui{windowMain}, 'watch');
     my $gref = &getsel_list_guest();
     my $sref = &get_session($$gref{IMachine});
 
@@ -1319,10 +1328,10 @@ sub clear_group {
     }
 
     ISession_unlockMachine($$sref{ISession}) if (ISession_getState($$sref{ISession}) eq 'Locked');
-    &busy_pointer($gui{windowMain}, 0);
+    &set_pointer($gui{windowMain});
 }
 
-# Update the server memory progress bar
+# Update the server memory progress bar - also called from a timer
 sub update_server_membar {
     if ($gui{websn}) {
         my $IHost = IVirtualBox_getHost($gui{websn});
@@ -1332,6 +1341,7 @@ sub update_server_membar {
         $gui{progressbarMem}->set_text("Memory ($memsize MB): $memused MB Used / $memavail MB Free");
         $gui{progressbarMem}->set_fraction(($memused / $memsize));
     }
+
     return 1; # Return 1 to stop the timer from being removed
 }
 
