@@ -27,7 +27,7 @@ sub show_dialog_new_guest {
                           } keys %{$osfam}) {
 
         my $iter = $gui{liststoreNewOSFam}->append();
-        $gui{liststoreNewOSFam}->set($iter, 0, "$$osfam{$fam}{description}", 1, $fam, 2, $$osfam{$fam}{icon});
+        $gui{liststoreNewOSFam}->set($iter, [0, 1, 2], ["$$osfam{$fam}{description}", $fam, $$osfam{$fam}{icon}]);
         $gui{comboboxNewOSFam}->set_active_iter($iter) if ($fam eq 'Windows');
     }
 
@@ -36,7 +36,7 @@ sub show_dialog_new_guest {
     if (keys(%$IMediumRef) > 0) {
         foreach my $hd (sort { lc($$IMediumRef{$a}) cmp lc($$IMediumRef{$b}) } (keys(%$IMediumRef))) {
             my $iter = $gui{liststoreNewChooseHD}->append();
-            $gui{liststoreNewChooseHD}->set($iter, 0, $$IMediumRef{$hd}, 1, $hd);
+            $gui{liststoreNewChooseHD}->set($iter, [0, 1], [$$IMediumRef{$hd}, $hd]);
         }
 
         $gui{comboboxNewChooseHD}->set_active(0);
@@ -127,7 +127,7 @@ sub show_dialog_new_guest {
         }
         else { $gui{dialogNew}->hide; }
 
-    } until (!$gui{dialogNew}->visible());
+    } until (!$gui{dialogNew}->get_visible());
 }
 
 # Shows the dialog for creating a new clone
@@ -167,7 +167,7 @@ sub show_dialog_clone {
         }
         else { $gui{dialogClone}->hide; }
 
-    } until (!$gui{dialogClone}->visible());
+    } until (!$gui{dialogClone}->get_visible());
 }
 
 # Determines the next free port number and device number on a controller. If
@@ -251,11 +251,10 @@ sub create_new_clone {
 # Creates a clone of a disk image
 sub create_new_dskimg_clone {
     my ($newref, $srcIMedium) = @_;
-    $$newref{imgformat} = lc($$newref{imgformat}); # Force it to be lower case
-    my $fileext = &fileext();
-    my $imgfile = &rcatfile($$newref{location}, "$$newref{diskname}.$$fileext{$$newref{imgformat}}");
+    my $imgfile = &rcatfile($$newref{location}, $$newref{diskname});
+    $imgfile = &add_ext_if_needed($imgfile, $$newref{imgformat});
     my $IMedium = IVirtualBox_createMedium($gui{websn}, $$newref{imgformat}, $imgfile, $$newref{mode}, $$newref{devicetype});
-    my $IProgress = IMedium_cloneTo($srcIMedium, $IMedium, @{$$newref{allocation}}, undef);
+    my $IProgress = IMedium_cloneTo($srcIMedium, $IMedium, $$newref{allocation}, undef);
     &show_progress_window($IProgress, 'Copying or Cloning Disk Image', $gui{img}{ProgressMediaCreate});
 
     if (IProgress_getCanceled($IProgress) eq 'true') {
@@ -268,18 +267,19 @@ sub create_new_dskimg_clone {
         IManagedObjectRef_release($IMedium);
         $IMedium = undef;
     }
-    else { &addrow_log("Copied or cloned disk image to new file: $imgfile"); }
+    else {
+        &addrow_log("Copied or cloned disk image to new file: $imgfile");
+    }
 
-    Gtk2->main_iteration() while Gtk2->events_pending();
+    Gtk3::main_iteration while Gtk3::events_pending;
     return $IMedium;
 }
 
 # Creates a new hard disk or floppy image and shows a progress window
 sub create_new_dskimg {
     my ($newref) = @_;
-    $$newref{imgformat} = lc($$newref{imgformat}); # Force it to be lower case
-    my $fileext = &fileext();
-    my $imgfile = &rcatfile($$newref{location}, "$$newref{diskname}.$$fileext{$$newref{imgformat}}");
+    my $imgfile = &rcatfile($$newref{location}, $$newref{diskname});
+    $imgfile = &add_ext_if_needed($imgfile, $$newref{imgformat});
     my $IMedium = IVirtualBox_createMedium($gui{websn}, $$newref{imgformat}, $imgfile, $$newref{mode}, $$newref{devicetype});
     # Note: Modified in the vboxService.pm. We expect an array reference in $$newref{allocation}
     my $IProgress = IMedium_createBaseStorage($IMedium, $$newref{size}, @{$$newref{allocation}});
@@ -295,9 +295,11 @@ sub create_new_dskimg {
         IManagedObjectRef_release($IMedium);
         $IMedium = undef;
     }
-    else { &addrow_log("Created new disk image: $imgfile"); }
+    else {
+        &addrow_log("Created new disk image: $imgfile");
+    }
 
-    Gtk2->main_iteration() while Gtk2->events_pending();
+    Gtk3::main_iteration while Gtk3::events_pending;
     return $IMedium;
 }
 
@@ -312,7 +314,7 @@ sub newgen_osfam {
     foreach my $ver (@{ $$osfam{$fam}{verids} })
     {
         my $iter = $gui{liststoreNewOSVer}->append();
-        $gui{liststoreNewOSVer}->set($iter, 0, $$osver{$ver}{description}, 1, $ver, 2, $$osver{$ver}{icon});
+        $gui{liststoreNewOSVer}->set($iter, [0, 1, 2], [$$osver{$ver}{description}, $ver, $$osver{$ver}{icon}]);
         $combover->set_active_iter($iter) if ($ver eq 'Windows10_64' | $ver eq 'Fedora_64' | $ver eq 'Solaris11_64' | $ver eq 'FreeBSD_64' | $ver eq 'DOS');
     }
 
