@@ -4,10 +4,8 @@ use warnings;
 our %gui;
 our %prefs = (RDPCLIENT         => 'xfreerdp /size:%Xx%Y /bpp:32 +clipboard /sound /t:"%n - RemoteBox" /v:%h:%p',
               VNCCLIENT         => 'vncviewer -Shared -AcceptClipboard -SetPrimary -SendClipboard -SendPrimary -RemoteResize -DesktopSize %Xx%Y  %h:%p',
-              HEARTBEAT         => 1,
               ADDADDITIONS      => 1,
               RDPAUTOOPEN       => 1,
-              MSGLOGEXPAND      => 1,
               GUESTLISTEXPAND   => 1,
               AUTOSORTGUESTLIST => 1,
               EXTENDEDDETAILS   => 0,
@@ -40,8 +38,8 @@ sub rbprefs_get {
     $gui{THUMBDIR} = "$gui{PREFSDIR}/remoteboxthumbs";
 
     # See if we can make some more useful defaults for OSs which don't have xfreerdp
-    if ($^O =~ m/netbsd/i) { $prefs{RDPCLIENT} = 'rdesktop -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'; }
-    elsif ($^O =~ m/solaris/i) { $prefs{RDPCLIENT} = 'rdesktop -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'; }
+    if ($^O =~ m/netbsd/i) { $prefs{RDPCLIENT} = 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'; }
+    elsif ($^O =~ m/solaris/i) { $prefs{RDPCLIENT} = 'rdesktop -g %Xx%Y -r sound:local -r clipboard:PRIMARYCLIPBOARD -T "%n - RemoteBox" %h:%p'; }
     elsif ($^O =~ m/MSWin/) { $prefs{RDPCLIENT} = 'mstsc /w:%X /h:%Y /v:%h:%p'; }
 
     if (open(PREFS, '<', $gui{CONFIGFILE})) {
@@ -56,7 +54,6 @@ sub rbprefs_get {
     }
     else { $prefs{URL}{qq[http://localhost:18083]} = 'URL'; } #Add a default URL
 
-    $gui{expanderMessages}->set_expanded($prefs{MSGLOGEXPAND});
     $gui{checkbuttonShowDetails}->set_active($prefs{EXTENDEDDETAILS});
 
     # Load in the connection profiles
@@ -128,8 +125,7 @@ sub rbprofiles_save {
 # Save RemoteBox's window position for restoration later
 sub save_window_pos {
     my ($winname) = @_;
-    my $alloc = $gui{$winname}->allocation;
-    my ($w, $h) = ($alloc->width, $alloc->height);
+    my ($w, $h) = $gui{$winname}->get_size();
     my ($x,$y) = $gui{$winname}->get_position();
     $prefs{"WINPOS_$winname"} = "$w:$h:$x:$y";
     &rbprefs_save();
@@ -142,8 +138,8 @@ sub show_dialog_editnat {
     $gui{checkbuttonvbprefsNATDHCP}->set_active(&bl(INATNetwork_getNeedDhcpServer($$natref{INATNetwork})));
     $gui{checkbuttonvbprefsNATipv6}->set_active(&bl(INATNetwork_getIPv6Enabled($$natref{INATNetwork})));
     $gui{checkbuttonvbprefsNATipv6route}->set_active(&bl(INATNetwork_getAdvertiseDefaultIPv6RouteEnabled($$natref{INATNetwork})));
-    &fill_list_pf4($$natref{INATNetwork});
-    &fill_list_pf6($$natref{INATNetwork});
+    #&fill_list_pf4($$natref{INATNetwork});
+    #&fill_list_pf6($$natref{INATNetwork});
 
     do {
         my $response = $gui{dialogNATDetails}->run;
@@ -164,7 +160,7 @@ sub show_dialog_editnat {
         }
         else { $gui{dialogNATDetails}->hide; }
 
-    } until (!$gui{dialogNATDetails}->visible());
+    } until (!$gui{dialogNATDetails}->get_visible());
 }
 
 # Show dialog for adding an IPv4 port forwarding rule
@@ -195,7 +191,7 @@ sub show_dialog_pf4 {
         }
         else { $gui{dialogPFIPv4}->hide; }
 
-    } until (!$gui{dialogPFIPv4}->visible());
+    } until (!$gui{dialogPFIPv4}->get_visible());
 }
 
 # Show dialog for adding an IPv6 port forwarding rule
@@ -226,7 +222,7 @@ sub show_dialog_pf6 {
         }
         else { $gui{dialogPFIPv6}->hide; }
 
-    } until (!$gui{dialogPFIPv6}->visible());
+    } until (!$gui{dialogPFIPv6}->get_visible());
 }
 
 # Removes an IPv4 port forwarding rule to the selected NAT Network
@@ -248,7 +244,6 @@ sub show_dialog_prefs {
     $gui{entryPrefsRDPClient}->set_text($prefs{RDPCLIENT});
     $gui{entryPrefsVNCClient}->set_text($prefs{VNCCLIENT});
     $gui{checkbuttonPrefsRDPAuto}->set_active($prefs{RDPAUTOOPEN});
-    $gui{checkbuttonPrefsHeartbeat}->set_active($prefs{HEARTBEAT});
     $gui{checkbuttonPrefsAddAdditions}->set_active($prefs{ADDADDITIONS});
     $gui{checkbuttonPrefsAutoSortGuestList}->set_active($prefs{AUTOSORTGUESTLIST});
     $gui{checkbuttonPrefsAutoHint}->set_active($prefs{AUTOHINTDISP});
@@ -270,7 +265,6 @@ sub show_dialog_prefs {
         $prefs{RDPCLIENT} = $gui{entryPrefsRDPClient}->get_text();
         $prefs{VNCCLIENT} = $gui{entryPrefsVNCClient}->get_text();
         $prefs{RDPAUTOOPEN} = int($gui{checkbuttonPrefsRDPAuto}->get_active());
-        $prefs{HEARTBEAT} = int($gui{checkbuttonPrefsHeartbeat}->get_active());
         $prefs{ADDADDITIONS} = int($gui{checkbuttonPrefsAddAdditions}->get_active());
         $prefs{AUTOSORTGUESTLIST} = int($gui{checkbuttonPrefsAutoSortGuestList}->get_active());
         $prefs{STOPTYPE} = &getsel_combo($gui{comboboxPrefsDefaultStop}, 1);
@@ -374,7 +368,7 @@ sub show_dialog_edithon {
         }
         else { $gui{dialogHON}->hide(); }
 
-    } until (!$gui{dialogHON}->visible());
+    } until (!$gui{dialogHON}->get_visible());
 }
 
 sub vbprefs_reset {
@@ -430,19 +424,13 @@ sub vbprefs_removenat {
 # Can't use getsel_list_vbprefsnat in here due to the way the signals are propagated
 sub vbprefs_togglenat {
     my ($widget, $path_str, $model) = @_;
-    my $iter = $model->get_iter(Gtk2::TreePath->new_from_string($path_str));
+    my $iter = $model->get_iter(Gtk3::TreePath->new_from_string($path_str));
     my $val = $model->get($iter, 0);
     my $INATNetwork = $model->get($iter, 2);
     INATNetwork_setEnabled($INATNetwork, !$val);
     &fill_list_vbprefsnat();
 }
 
-sub rbprefs_msglog {
-    my ($widget) = @_;
-    $prefs{MSGLOGEXPAND} = int($widget->get_expanded()); # int forces 0 on undefined
-    &rbprefs_save();
-}
-
 sub rbprefs_sslverify {
     my $active = $gui{checkbuttonConnectSSL}->get_active();
     $ENV{PERL_LWP_SSL_VERIFY_HOSTNAME} = $active;
@@ -450,19 +438,6 @@ sub rbprefs_sslverify {
     &rbprefs_save();
 }
 
-sub rbprefs_autohint {
-    if ($gui{checkbuttonPrefsAutoHint}->get_active()) {
-        $gui{spinbuttonPrefsWidth}->set_sensitive(1);
-        $gui{spinbuttonPrefsHeight}->set_sensitive(1);
-        $gui{comboboxPrefsDepth}->set_sensitive(1);
-    }
-    else {
-        $gui{spinbuttonPrefsWidth}->set_sensitive(0);
-        $gui{spinbuttonPrefsHeight}->set_sensitive(0);
-        $gui{comboboxPrefsDepth}->set_sensitive(0);
-    }
-}
-
 sub vbprefs_hon_dhcp_toggle {
     $gui{tableHONDHCP}->set_sensitive($gui{checkbuttonHONDHCP}->get_active()); # Ghost/Unghost other widgets based on dhcp enabled
 }
